==> haskell-indexed-traversable-instances-0.1.2-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-indexed-traversable-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 indexed-traversable-instances
version:              0.1.2
visibility:           public
id:                   indexed-traversable-instances-0.1.2-9qQtf3YEGdT3QZu2jNEzci
key:                  indexed-traversable-instances-0.1.2-9qQtf3YEGdT3QZu2jNEzci
license:              BSD-2-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Edward Kmett
synopsis:
    More instances of FunctorWithIndex, FoldableWithIndex, TraversableWithIndex

description:
    This package provides extra instances for type-classes in the [indexed-traversable](https://hackage.haskell.org/package/indexed-traversable) package.

    The intention is to keep this package minimal;
    it provides instances that formely existed in @lens@ or @optics-extra@.
    We recommend putting other instances directly into their defining packages.
    The @indexed-traversable@ package is light, having only GHC boot libraries
    as its dependencies.

category:             Data
abi:                  2f5a2b79475a09750e8bfca88675843e
exposed:              True
exposed-modules:      Data.Functor.WithIndex.Instances
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/indexed-traversable-instances-0.1.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/indexed-traversable-instances-0.1.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/indexed-traversable-instances-0.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-indexed-traversable-instances
hs-libraries:
    HSindexed-traversable-instances-0.1.2-9qQtf3YEGdT3QZu2jNEzci

depends:
    OneTuple-0.4.2-eWZ1mKfuDAGDCurcBiit2 base-4.17.2.1
    indexed-traversable-0.1.4-1tFXRvGW7UrI48oXduZgU9
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    unordered-containers-0.2.20-HNPxulgNQi0FiQ3NUpCOne
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8

haddock-interfaces:
    /usr/share/doc/haskell-indexed-traversable-instances/html/indexed-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-indexed-traversable-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-indexed-traversable-instances-0.1.2-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-indexed-traversable-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 indexed-traversable-instances
version:              0.1.2
visibility:           public
id:                   indexed-traversable-instances-0.1.2-1YTpY54GI7r3w3ggoIoqJS
key:                  indexed-traversable-instances-0.1.2-1YTpY54GI7r3w3ggoIoqJS
license:              BSD-2-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Edward Kmett
synopsis:
    More instances of FunctorWithIndex, FoldableWithIndex, TraversableWithIndex

description:
    This package provides extra instances for type-classes in the [indexed-traversable](https://hackage.haskell.org/package/indexed-traversable) package.

    The intention is to keep this package minimal;
    it provides instances that formely existed in @lens@ or @optics-extra@.
    We recommend putting other instances directly into their defining packages.
    The @indexed-traversable@ package is light, having only GHC boot libraries
    as its dependencies.

category:             Data
abi:                  2db6092026534cf18f28c4a2b838bbd3
exposed:              True
exposed-modules:      Data.Functor.WithIndex.Instances
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/indexed-traversable-instances-0.1.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/indexed-traversable-instances-0.1.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/indexed-traversable-instances-0.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-indexed-traversable-instances
hs-libraries:
    HSindexed-traversable-instances-0.1.2-1YTpY54GI7r3w3ggoIoqJS

depends:
    OneTuple-0.4.2-eWZ1mKfuDAGDCurcBiit2 base-4.17.2.1
    indexed-traversable-0.1.4-GpzHE24npZbHvtNh8tX2xS
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    unordered-containers-0.2.20-vB8Yx6KwyeBrT13JKFJ0i
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8

haddock-interfaces:
    /usr/share/doc/haskell-indexed-traversable-instances/html/indexed-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-indexed-traversable-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
